::: aliceio.fsm.middlewares.api_storage.FSMApiStorageMiddleware
    handler: python
    options:
      members:
        - __call__
        - pre_set_state
        - resolve_state_data
        - post_update_state
        - set_new_state
